@@ -49,7 +49,8 @@ class StreamingRecordWriter : public RecordWriter
     explicit StreamingRecordWriter(
             std::unique_ptr<memray::io::Sink> sink,
             const std::string& command_line,
-            bool native_traces);
+            bool native_traces,
+            bool trace_python_allocators);
 
     StreamingRecordWriter(StreamingRecordWriter& other) = delete;
     StreamingRecordWriter(StreamingRecordWriter&& other) = delete;
@@ -90,7 +91,8 @@ class AggregatingRecordWriter : public RecordWriter
     explicit AggregatingRecordWriter(
             std::unique_ptr<memray::io::Sink> sink,
             const std::string& command_line,
-            bool native_traces);
+            bool native_traces,
+            bool trace_python_allocators);
 
     AggregatingRecordWriter(StreamingRecordWriter& other) = delete;
     AggregatingRecordWriter(StreamingRecordWriter&& other) = delete;
@@ -138,16 +140,22 @@ createRecordWriter(
         std::unique_ptr<memray::io::Sink> sink,
         const std::string& command_line,
         bool native_traces,
-        FileFormat file_format)
+        FileFormat file_format,
+        bool trace_python_allocators)
 {
     switch (file_format) {
         case FileFormat::ALL_ALLOCATIONS:
-            return std::make_unique<StreamingRecordWriter>(std::move(sink), command_line, native_traces);
+            return std::make_unique<StreamingRecordWriter>(
+                    std::move(sink),
+                    command_line,
+                    native_traces,
+                    trace_python_allocators);
         case FileFormat::AGGREGATED_ALLOCATIONS:
             return std::make_unique<AggregatingRecordWriter>(
                     std::move(sink),
                     command_line,
-                    native_traces);
+                    native_traces,
+                    trace_python_allocators);
         default:
             throw std::runtime_error("Invalid file format enumerator");
     }
@@ -156,7 +164,8 @@ createRecordWriter(
 StreamingRecordWriter::StreamingRecordWriter(
         std::unique_ptr<memray::io::Sink> sink,
         const std::string& command_line,
-        bool native_traces)
+        bool native_traces,
+        bool trace_python_allocators)
 : RecordWriter(std::move(sink))
 , d_stats({0, 0, duration_cast<milliseconds>(system_clock::now().time_since_epoch()).count()})
 {
@@ -170,7 +179,8 @@ StreamingRecordWriter::StreamingRecordWriter(
             ::getpid(),
             0,
             0,
-            getPythonAllocator()};
+            getPythonAllocator(),
+            trace_python_allocators};
     strncpy(d_header.magic, MAGIC, sizeof(d_header.magic));
 }
 
@@ -235,7 +245,8 @@ RecordWriter::writeMappingsCommon(const std::vector<ImageSegments>& mappings)
 
         for (const auto& segment : image.segments) {
             if (!writeSimpleType(segment_token) || !writeSimpleType(segment.vaddr)
-                || !writeVarint(segment.memsz)) {
+                || !writeVarint(segment.memsz))
+            {
                 return false;
             }
         }
@@ -356,7 +367,7 @@ RecordWriter::writeHeaderCommon(const HeaderRecord& header)
         or !writeSimpleType(header.stats) or !writeString(header.command_line.c_str())
         or !writeSimpleType(header.pid) or !writeSimpleType(header.main_tid)
         or !writeSimpleType(header.skipped_frames_on_main_tid)
-        or !writeSimpleType(header.python_allocator))
+        or !writeSimpleType(header.python_allocator) or !writeSimpleType(header.trace_python_allocators))
     {
         return false;
     }
@@ -382,13 +393,15 @@ StreamingRecordWriter::cloneInChildProcess()
     return std::make_unique<StreamingRecordWriter>(
             std::move(new_sink),
             d_header.command_line,
-            d_header.native_traces);
+            d_header.native_traces,
+            d_header.trace_python_allocators);
 }
 
 AggregatingRecordWriter::AggregatingRecordWriter(
         std::unique_ptr<memray::io::Sink> sink,
         const std::string& command_line,
-        bool native_traces)
+        bool native_traces,
+        bool trace_python_allocators)
 : RecordWriter(std::move(sink))
 {
     memcpy(d_header.magic, MAGIC, sizeof(d_header.magic));
@@ -398,6 +411,7 @@ AggregatingRecordWriter::AggregatingRecordWriter(
     d_header.command_line = command_line;
     d_header.pid = ::getpid();
     d_header.python_allocator = getPythonAllocator();
+    d_header.trace_python_allocators = trace_python_allocators;
 
     d_stats.start_time = duration_cast<milliseconds>(system_clock::now().time_since_epoch()).count();
 }
@@ -511,7 +525,8 @@ AggregatingRecordWriter::cloneInChildProcess()
     return std::make_unique<AggregatingRecordWriter>(
             std::move(new_sink),
             d_header.command_line,
-            d_header.native_traces);
+            d_header.native_traces,
+            d_header.trace_python_allocators);
 }
 
 bool
